# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stfwire.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='stfwire.proto',
  package='jp.co.cyberagent.stf.proto',
  serialized_pb=_b('\n\rstfwire.proto\x12\x1ajp.co.cyberagent.stf.proto\"^\n\x08\x45nvelope\x12\n\n\x02id\x18\x01 \x01(\r\x12\x35\n\x04type\x18\x02 \x02(\x0e\x32\'.jp.co.cyberagent.stf.proto.MessageType\x12\x0f\n\x07message\x18\x03 \x02(\x0c\"$\n\x11\x41irplaneModeEvent\x12\x0f\n\x07\x65nabled\x18\x01 \x02(\x08\"{\n\x0c\x42\x61tteryEvent\x12\x0e\n\x06status\x18\x01 \x02(\t\x12\x0e\n\x06health\x18\x02 \x02(\t\x12\x0e\n\x06source\x18\x03 \x02(\t\x12\r\n\x05level\x18\x04 \x02(\r\x12\r\n\x05scale\x18\x05 \x02(\r\x12\x0c\n\x04temp\x18\x06 \x02(\x01\x12\x0f\n\x07voltage\x18\x07 \x02(\x01\"O\n\nBrowserApp\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x11\n\tcomponent\x18\x02 \x02(\t\x12\x10\n\x08selected\x18\x03 \x02(\x08\x12\x0e\n\x06system\x18\x04 \x02(\x08\"]\n\x13\x42rowserPackageEvent\x12\x10\n\x08selected\x18\x01 \x02(\x08\x12\x34\n\x04\x61pps\x18\x02 \x03(\x0b\x32&.jp.co.cyberagent.stf.proto.BrowserApp\"h\n\x11\x43onnectivityEvent\x12\x11\n\tconnected\x18\x01 \x02(\x08\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07subtype\x18\x03 \x01(\t\x12\x10\n\x08\x66\x61ilover\x18\x04 \x01(\x08\x12\x0f\n\x07roaming\x18\x05 \x01(\x08\"B\n\x0fPhoneStateEvent\x12\r\n\x05state\x18\x01 \x02(\t\x12\x0e\n\x06manual\x18\x02 \x02(\x08\x12\x10\n\x08operator\x18\x03 \x01(\t\"!\n\rRotationEvent\x12\x10\n\x08rotation\x18\x01 \x02(\x05\"\x13\n\x11GetVersionRequest\"6\n\x12GetVersionResponse\x12\x0f\n\x07success\x18\x01 \x02(\x08\x12\x0f\n\x07version\x18\x02 \x01(\t\"*\n\x17SetKeyguardStateRequest\x12\x0f\n\x07\x65nabled\x18\x01 \x02(\x08\"+\n\x18SetKeyguardStateResponse\x12\x0f\n\x07success\x18\x01 \x02(\x08\"%\n\x12SetWakeLockRequest\x12\x0f\n\x07\x65nabled\x18\x01 \x02(\x08\"&\n\x13SetWakeLockResponse\x12\x0f\n\x07success\x18\x01 \x02(\x08\"\\\n\x13SetClipboardRequest\x12\x37\n\x04type\x18\x01 \x02(\x0e\x32).jp.co.cyberagent.stf.proto.ClipboardType\x12\x0c\n\x04text\x18\x02 \x01(\t\"\'\n\x14SetClipboardResponse\x12\x0f\n\x07success\x18\x01 \x02(\x08\"N\n\x13GetClipboardRequest\x12\x37\n\x04type\x18\x01 \x02(\x0e\x32).jp.co.cyberagent.stf.proto.ClipboardType\"n\n\x14GetClipboardResponse\x12\x0f\n\x07success\x18\x01 \x02(\x08\x12\x37\n\x04type\x18\x02 \x01(\x0e\x32).jp.co.cyberagent.stf.proto.ClipboardType\x12\x0c\n\x04text\x18\x03 \x01(\t\"\x14\n\x12GetBrowsersRequest\"n\n\x13GetBrowsersResponse\x12\x0f\n\x07success\x18\x01 \x02(\x08\x12\x10\n\x08selected\x18\x02 \x02(\x08\x12\x34\n\x04\x61pps\x18\x03 \x03(\x0b\x32&.jp.co.cyberagent.stf.proto.BrowserApp\"\x1f\n\x11GetDisplayRequest\x12\n\n\x02id\x18\x01 \x02(\x05\"\xa0\x01\n\x12GetDisplayResponse\x12\x0f\n\x07success\x18\x01 \x02(\x08\x12\r\n\x05width\x18\x02 \x01(\x05\x12\x0e\n\x06height\x18\x03 \x01(\x05\x12\x0c\n\x04xdpi\x18\x04 \x01(\x02\x12\x0c\n\x04ydpi\x18\x05 \x01(\x02\x12\x0b\n\x03\x66ps\x18\x06 \x01(\x02\x12\x0f\n\x07\x64\x65nsity\x18\x07 \x01(\x02\x12\x10\n\x08rotation\x18\x08 \x01(\x05\x12\x0e\n\x06secure\x18\t \x01(\x08\"\'\n\x08Property\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t\"*\n\x14GetPropertiesRequest\x12\x12\n\nproperties\x18\x01 \x03(\t\"b\n\x15GetPropertiesResponse\x12\x0f\n\x07success\x18\x01 \x02(\x08\x12\x38\n\nproperties\x18\x02 \x03(\x0b\x32$.jp.co.cyberagent.stf.proto.Property\"#\n\x11\x44oIdentifyRequest\x12\x0e\n\x06serial\x18\x01 \x02(\t\"%\n\x12\x44oIdentifyResponse\x12\x0f\n\x07success\x18\x01 \x02(\x08\"\"\n\x12GetAccountsRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\"8\n\x13GetAccountsResponse\x12\x0f\n\x07success\x18\x01 \x02(\x08\x12\x10\n\x08\x61\x63\x63ounts\x18\x02 \x03(\t\"\x19\n\x17\x44oAddAccountMenuRequest\"+\n\x18\x44oAddAccountMenuResponse\x12\x0f\n\x07success\x18\x01 \x02(\x08\"7\n\x16\x44oRemoveAccountRequest\x12\x0c\n\x04type\x18\x01 \x02(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x02 \x01(\t\"*\n\x17\x44oRemoveAccountResponse\x12\x0f\n\x07success\x18\x01 \x02(\x08\"L\n\x14SetRingerModeRequest\x12\x34\n\x04mode\x18\x01 \x02(\x0e\x32&.jp.co.cyberagent.stf.proto.RingerMode\"(\n\x15SetRingerModeResponse\x12\x0f\n\x07success\x18\x01 \x02(\x08\"\x16\n\x14GetRingerModeRequest\"^\n\x15GetRingerModeResponse\x12\x0f\n\x07success\x18\x01 \x02(\x08\x12\x34\n\x04mode\x18\x02 \x02(\x0e\x32&.jp.co.cyberagent.stf.proto.RingerMode\"(\n\x15SetWifiEnabledRequest\x12\x0f\n\x07\x65nabled\x18\x01 \x02(\x08\")\n\x16SetWifiEnabledResponse\x12\x0f\n\x07success\x18\x01 \x02(\x08\"\x16\n\x14GetWifiStatusRequest\"8\n\x15GetWifiStatusResponse\x12\x0f\n\x07success\x18\x01 \x02(\x08\x12\x0e\n\x06status\x18\x02 \x02(\x08\"\x14\n\x12GetSdStatusRequest\"7\n\x13GetSdStatusResponse\x12\x0f\n\x07success\x18\x01 \x02(\x08\x12\x0f\n\x07mounted\x18\x02 \x02(\x08\"\'\n\x14SetMasterMuteRequest\x12\x0f\n\x07\x65nabled\x18\x01 \x02(\x08\"(\n\x15SetMasterMuteResponse\x12\x0f\n\x07success\x18\x01 \x02(\x08\"\x80\x02\n\x0fKeyEventRequest\x12\x33\n\x05\x65vent\x18\x01 \x02(\x0e\x32$.jp.co.cyberagent.stf.proto.KeyEvent\x12\x0f\n\x07keyCode\x18\x02 \x02(\x05\x12\x10\n\x08shiftKey\x18\x03 \x01(\x08\x12\x0f\n\x07\x63trlKey\x18\x04 \x01(\x08\x12\x0e\n\x06\x61ltKey\x18\x05 \x01(\x08\x12\x0f\n\x07metaKey\x18\x06 \x01(\x08\x12\x0e\n\x06symKey\x18\x07 \x01(\x08\x12\x13\n\x0b\x66unctionKey\x18\x08 \x01(\x08\x12\x13\n\x0b\x63\x61psLockKey\x18\t \x01(\x08\x12\x15\n\rscrollLockKey\x18\n \x01(\x08\x12\x12\n\nnumLockKey\x18\x0b \x01(\x08\"\x1d\n\rDoTypeRequest\x12\x0c\n\x04text\x18\x01 \x02(\t\"4\n\x12SetRotationRequest\x12\x10\n\x08rotation\x18\x01 \x02(\x05\x12\x0c\n\x04lock\x18\x02 \x02(\x08\"\x0f\n\rDoWakeRequest*\xbd\x04\n\x0bMessageType\x12\x0f\n\x0b\x44O_IDENTIFY\x10\x01\x12\x0f\n\x0b\x44O_KEYEVENT\x10\x02\x12\x0b\n\x07\x44O_TYPE\x10\x03\x12\x0b\n\x07\x44O_WAKE\x10\x04\x12\x17\n\x13\x44O_ADD_ACCOUNT_MENU\x10\x18\x12\x15\n\x11\x44O_REMOVE_ACCOUNT\x10\x14\x12\x10\n\x0cGET_ACCOUNTS\x10\x1a\x12\x10\n\x0cGET_BROWSERS\x10\x05\x12\x11\n\rGET_CLIPBOARD\x10\x06\x12\x0f\n\x0bGET_DISPLAY\x10\x13\x12\x12\n\x0eGET_PROPERTIES\x10\x07\x12\x13\n\x0fGET_RINGER_MODE\x10\x1b\x12\x11\n\rGET_SD_STATUS\x10\x19\x12\x0f\n\x0bGET_VERSION\x10\x08\x12\x13\n\x0fGET_WIFI_STATUS\x10\x17\x12\x11\n\rSET_CLIPBOARD\x10\t\x12\x16\n\x12SET_KEYGUARD_STATE\x10\n\x12\x13\n\x0fSET_RINGER_MODE\x10\x15\x12\x10\n\x0cSET_ROTATION\x10\x0c\x12\x11\n\rSET_WAKE_LOCK\x10\x0b\x12\x14\n\x10SET_WIFI_ENABLED\x10\x16\x12\x13\n\x0fSET_MASTER_MUTE\x10\x1c\x12\x17\n\x13\x45VENT_AIRPLANE_MODE\x10\r\x12\x11\n\rEVENT_BATTERY\x10\x0e\x12\x16\n\x12\x45VENT_CONNECTIVITY\x10\x0f\x12\x15\n\x11\x45VENT_PHONE_STATE\x10\x10\x12\x12\n\x0e\x45VENT_ROTATION\x10\x11\x12\x19\n\x15\x45VENT_BROWSER_PACKAGE\x10\x12*\x19\n\rClipboardType\x12\x08\n\x04TEXT\x10\x01*1\n\nRingerMode\x12\n\n\x06SILENT\x10\x00\x12\x0b\n\x07VIBRATE\x10\x01\x12\n\n\x06NORMAL\x10\x02*\'\n\x08KeyEvent\x12\x08\n\x04\x44OWN\x10\x00\x12\x06\n\x02UP\x10\x01\x12\t\n\x05PRESS\x10\x02\x42\x06\x42\x04Wire')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_MESSAGETYPE = _descriptor.EnumDescriptor(
  name='MessageType',
  full_name='jp.co.cyberagent.stf.proto.MessageType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DO_IDENTIFY', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DO_KEYEVENT', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DO_TYPE', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DO_WAKE', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DO_ADD_ACCOUNT_MENU', index=4, number=24,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DO_REMOVE_ACCOUNT', index=5, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GET_ACCOUNTS', index=6, number=26,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GET_BROWSERS', index=7, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GET_CLIPBOARD', index=8, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GET_DISPLAY', index=9, number=19,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GET_PROPERTIES', index=10, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GET_RINGER_MODE', index=11, number=27,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GET_SD_STATUS', index=12, number=25,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GET_VERSION', index=13, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GET_WIFI_STATUS', index=14, number=23,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SET_CLIPBOARD', index=15, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SET_KEYGUARD_STATE', index=16, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SET_RINGER_MODE', index=17, number=21,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SET_ROTATION', index=18, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SET_WAKE_LOCK', index=19, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SET_WIFI_ENABLED', index=20, number=22,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SET_MASTER_MUTE', index=21, number=28,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_AIRPLANE_MODE', index=22, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_BATTERY', index=23, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_CONNECTIVITY', index=24, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_PHONE_STATE', index=25, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ROTATION', index=26, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_BROWSER_PACKAGE', index=27, number=18,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3050,
  serialized_end=3623,
)
_sym_db.RegisterEnumDescriptor(_MESSAGETYPE)

MessageType = enum_type_wrapper.EnumTypeWrapper(_MESSAGETYPE)
_CLIPBOARDTYPE = _descriptor.EnumDescriptor(
  name='ClipboardType',
  full_name='jp.co.cyberagent.stf.proto.ClipboardType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TEXT', index=0, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3625,
  serialized_end=3650,
)
_sym_db.RegisterEnumDescriptor(_CLIPBOARDTYPE)

ClipboardType = enum_type_wrapper.EnumTypeWrapper(_CLIPBOARDTYPE)
_RINGERMODE = _descriptor.EnumDescriptor(
  name='RingerMode',
  full_name='jp.co.cyberagent.stf.proto.RingerMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SILENT', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIBRATE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NORMAL', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3652,
  serialized_end=3701,
)
_sym_db.RegisterEnumDescriptor(_RINGERMODE)

RingerMode = enum_type_wrapper.EnumTypeWrapper(_RINGERMODE)
_KEYEVENT = _descriptor.EnumDescriptor(
  name='KeyEvent',
  full_name='jp.co.cyberagent.stf.proto.KeyEvent',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UP', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRESS', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3703,
  serialized_end=3742,
)
_sym_db.RegisterEnumDescriptor(_KEYEVENT)

KeyEvent = enum_type_wrapper.EnumTypeWrapper(_KEYEVENT)
DO_IDENTIFY = 1
DO_KEYEVENT = 2
DO_TYPE = 3
DO_WAKE = 4
DO_ADD_ACCOUNT_MENU = 24
DO_REMOVE_ACCOUNT = 20
GET_ACCOUNTS = 26
GET_BROWSERS = 5
GET_CLIPBOARD = 6
GET_DISPLAY = 19
GET_PROPERTIES = 7
GET_RINGER_MODE = 27
GET_SD_STATUS = 25
GET_VERSION = 8
GET_WIFI_STATUS = 23
SET_CLIPBOARD = 9
SET_KEYGUARD_STATE = 10
SET_RINGER_MODE = 21
SET_ROTATION = 12
SET_WAKE_LOCK = 11
SET_WIFI_ENABLED = 22
SET_MASTER_MUTE = 28
EVENT_AIRPLANE_MODE = 13
EVENT_BATTERY = 14
EVENT_CONNECTIVITY = 15
EVENT_PHONE_STATE = 16
EVENT_ROTATION = 17
EVENT_BROWSER_PACKAGE = 18
TEXT = 1
SILENT = 0
VIBRATE = 1
NORMAL = 2
DOWN = 0
UP = 1
PRESS = 2



_ENVELOPE = _descriptor.Descriptor(
  name='Envelope',
  full_name='jp.co.cyberagent.stf.proto.Envelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='jp.co.cyberagent.stf.proto.Envelope.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='jp.co.cyberagent.stf.proto.Envelope.type', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='jp.co.cyberagent.stf.proto.Envelope.message', index=2,
      number=3, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=139,
)


_AIRPLANEMODEEVENT = _descriptor.Descriptor(
  name='AirplaneModeEvent',
  full_name='jp.co.cyberagent.stf.proto.AirplaneModeEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='jp.co.cyberagent.stf.proto.AirplaneModeEvent.enabled', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=141,
  serialized_end=177,
)


_BATTERYEVENT = _descriptor.Descriptor(
  name='BatteryEvent',
  full_name='jp.co.cyberagent.stf.proto.BatteryEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='jp.co.cyberagent.stf.proto.BatteryEvent.status', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='health', full_name='jp.co.cyberagent.stf.proto.BatteryEvent.health', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='source', full_name='jp.co.cyberagent.stf.proto.BatteryEvent.source', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='level', full_name='jp.co.cyberagent.stf.proto.BatteryEvent.level', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scale', full_name='jp.co.cyberagent.stf.proto.BatteryEvent.scale', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='temp', full_name='jp.co.cyberagent.stf.proto.BatteryEvent.temp', index=5,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='voltage', full_name='jp.co.cyberagent.stf.proto.BatteryEvent.voltage', index=6,
      number=7, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=179,
  serialized_end=302,
)


_BROWSERAPP = _descriptor.Descriptor(
  name='BrowserApp',
  full_name='jp.co.cyberagent.stf.proto.BrowserApp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='jp.co.cyberagent.stf.proto.BrowserApp.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='component', full_name='jp.co.cyberagent.stf.proto.BrowserApp.component', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='selected', full_name='jp.co.cyberagent.stf.proto.BrowserApp.selected', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='system', full_name='jp.co.cyberagent.stf.proto.BrowserApp.system', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=304,
  serialized_end=383,
)


_BROWSERPACKAGEEVENT = _descriptor.Descriptor(
  name='BrowserPackageEvent',
  full_name='jp.co.cyberagent.stf.proto.BrowserPackageEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='selected', full_name='jp.co.cyberagent.stf.proto.BrowserPackageEvent.selected', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='apps', full_name='jp.co.cyberagent.stf.proto.BrowserPackageEvent.apps', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=385,
  serialized_end=478,
)


_CONNECTIVITYEVENT = _descriptor.Descriptor(
  name='ConnectivityEvent',
  full_name='jp.co.cyberagent.stf.proto.ConnectivityEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='connected', full_name='jp.co.cyberagent.stf.proto.ConnectivityEvent.connected', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='jp.co.cyberagent.stf.proto.ConnectivityEvent.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subtype', full_name='jp.co.cyberagent.stf.proto.ConnectivityEvent.subtype', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='failover', full_name='jp.co.cyberagent.stf.proto.ConnectivityEvent.failover', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='roaming', full_name='jp.co.cyberagent.stf.proto.ConnectivityEvent.roaming', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=480,
  serialized_end=584,
)


_PHONESTATEEVENT = _descriptor.Descriptor(
  name='PhoneStateEvent',
  full_name='jp.co.cyberagent.stf.proto.PhoneStateEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='jp.co.cyberagent.stf.proto.PhoneStateEvent.state', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='manual', full_name='jp.co.cyberagent.stf.proto.PhoneStateEvent.manual', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='operator', full_name='jp.co.cyberagent.stf.proto.PhoneStateEvent.operator', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=586,
  serialized_end=652,
)


_ROTATIONEVENT = _descriptor.Descriptor(
  name='RotationEvent',
  full_name='jp.co.cyberagent.stf.proto.RotationEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rotation', full_name='jp.co.cyberagent.stf.proto.RotationEvent.rotation', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=654,
  serialized_end=687,
)


_GETVERSIONREQUEST = _descriptor.Descriptor(
  name='GetVersionRequest',
  full_name='jp.co.cyberagent.stf.proto.GetVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=689,
  serialized_end=708,
)


_GETVERSIONRESPONSE = _descriptor.Descriptor(
  name='GetVersionResponse',
  full_name='jp.co.cyberagent.stf.proto.GetVersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='jp.co.cyberagent.stf.proto.GetVersionResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='jp.co.cyberagent.stf.proto.GetVersionResponse.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=710,
  serialized_end=764,
)


_SETKEYGUARDSTATEREQUEST = _descriptor.Descriptor(
  name='SetKeyguardStateRequest',
  full_name='jp.co.cyberagent.stf.proto.SetKeyguardStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='jp.co.cyberagent.stf.proto.SetKeyguardStateRequest.enabled', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=766,
  serialized_end=808,
)


_SETKEYGUARDSTATERESPONSE = _descriptor.Descriptor(
  name='SetKeyguardStateResponse',
  full_name='jp.co.cyberagent.stf.proto.SetKeyguardStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='jp.co.cyberagent.stf.proto.SetKeyguardStateResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=810,
  serialized_end=853,
)


_SETWAKELOCKREQUEST = _descriptor.Descriptor(
  name='SetWakeLockRequest',
  full_name='jp.co.cyberagent.stf.proto.SetWakeLockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='jp.co.cyberagent.stf.proto.SetWakeLockRequest.enabled', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=855,
  serialized_end=892,
)


_SETWAKELOCKRESPONSE = _descriptor.Descriptor(
  name='SetWakeLockResponse',
  full_name='jp.co.cyberagent.stf.proto.SetWakeLockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='jp.co.cyberagent.stf.proto.SetWakeLockResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=894,
  serialized_end=932,
)


_SETCLIPBOARDREQUEST = _descriptor.Descriptor(
  name='SetClipboardRequest',
  full_name='jp.co.cyberagent.stf.proto.SetClipboardRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='jp.co.cyberagent.stf.proto.SetClipboardRequest.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='text', full_name='jp.co.cyberagent.stf.proto.SetClipboardRequest.text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=934,
  serialized_end=1026,
)


_SETCLIPBOARDRESPONSE = _descriptor.Descriptor(
  name='SetClipboardResponse',
  full_name='jp.co.cyberagent.stf.proto.SetClipboardResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='jp.co.cyberagent.stf.proto.SetClipboardResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1028,
  serialized_end=1067,
)


_GETCLIPBOARDREQUEST = _descriptor.Descriptor(
  name='GetClipboardRequest',
  full_name='jp.co.cyberagent.stf.proto.GetClipboardRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='jp.co.cyberagent.stf.proto.GetClipboardRequest.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1069,
  serialized_end=1147,
)


_GETCLIPBOARDRESPONSE = _descriptor.Descriptor(
  name='GetClipboardResponse',
  full_name='jp.co.cyberagent.stf.proto.GetClipboardResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='jp.co.cyberagent.stf.proto.GetClipboardResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='jp.co.cyberagent.stf.proto.GetClipboardResponse.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='text', full_name='jp.co.cyberagent.stf.proto.GetClipboardResponse.text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1149,
  serialized_end=1259,
)


_GETBROWSERSREQUEST = _descriptor.Descriptor(
  name='GetBrowsersRequest',
  full_name='jp.co.cyberagent.stf.proto.GetBrowsersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1261,
  serialized_end=1281,
)


_GETBROWSERSRESPONSE = _descriptor.Descriptor(
  name='GetBrowsersResponse',
  full_name='jp.co.cyberagent.stf.proto.GetBrowsersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='jp.co.cyberagent.stf.proto.GetBrowsersResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='selected', full_name='jp.co.cyberagent.stf.proto.GetBrowsersResponse.selected', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='apps', full_name='jp.co.cyberagent.stf.proto.GetBrowsersResponse.apps', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1283,
  serialized_end=1393,
)


_GETDISPLAYREQUEST = _descriptor.Descriptor(
  name='GetDisplayRequest',
  full_name='jp.co.cyberagent.stf.proto.GetDisplayRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='jp.co.cyberagent.stf.proto.GetDisplayRequest.id', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1395,
  serialized_end=1426,
)


_GETDISPLAYRESPONSE = _descriptor.Descriptor(
  name='GetDisplayResponse',
  full_name='jp.co.cyberagent.stf.proto.GetDisplayResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='jp.co.cyberagent.stf.proto.GetDisplayResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='width', full_name='jp.co.cyberagent.stf.proto.GetDisplayResponse.width', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='height', full_name='jp.co.cyberagent.stf.proto.GetDisplayResponse.height', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='xdpi', full_name='jp.co.cyberagent.stf.proto.GetDisplayResponse.xdpi', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ydpi', full_name='jp.co.cyberagent.stf.proto.GetDisplayResponse.ydpi', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fps', full_name='jp.co.cyberagent.stf.proto.GetDisplayResponse.fps', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='density', full_name='jp.co.cyberagent.stf.proto.GetDisplayResponse.density', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rotation', full_name='jp.co.cyberagent.stf.proto.GetDisplayResponse.rotation', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='secure', full_name='jp.co.cyberagent.stf.proto.GetDisplayResponse.secure', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1429,
  serialized_end=1589,
)


_PROPERTY = _descriptor.Descriptor(
  name='Property',
  full_name='jp.co.cyberagent.stf.proto.Property',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='jp.co.cyberagent.stf.proto.Property.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='jp.co.cyberagent.stf.proto.Property.value', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1591,
  serialized_end=1630,
)


_GETPROPERTIESREQUEST = _descriptor.Descriptor(
  name='GetPropertiesRequest',
  full_name='jp.co.cyberagent.stf.proto.GetPropertiesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='properties', full_name='jp.co.cyberagent.stf.proto.GetPropertiesRequest.properties', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1632,
  serialized_end=1674,
)


_GETPROPERTIESRESPONSE = _descriptor.Descriptor(
  name='GetPropertiesResponse',
  full_name='jp.co.cyberagent.stf.proto.GetPropertiesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='jp.co.cyberagent.stf.proto.GetPropertiesResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='properties', full_name='jp.co.cyberagent.stf.proto.GetPropertiesResponse.properties', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1676,
  serialized_end=1774,
)


_DOIDENTIFYREQUEST = _descriptor.Descriptor(
  name='DoIdentifyRequest',
  full_name='jp.co.cyberagent.stf.proto.DoIdentifyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='serial', full_name='jp.co.cyberagent.stf.proto.DoIdentifyRequest.serial', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1776,
  serialized_end=1811,
)


_DOIDENTIFYRESPONSE = _descriptor.Descriptor(
  name='DoIdentifyResponse',
  full_name='jp.co.cyberagent.stf.proto.DoIdentifyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='jp.co.cyberagent.stf.proto.DoIdentifyResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1813,
  serialized_end=1850,
)


_GETACCOUNTSREQUEST = _descriptor.Descriptor(
  name='GetAccountsRequest',
  full_name='jp.co.cyberagent.stf.proto.GetAccountsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='jp.co.cyberagent.stf.proto.GetAccountsRequest.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1852,
  serialized_end=1886,
)


_GETACCOUNTSRESPONSE = _descriptor.Descriptor(
  name='GetAccountsResponse',
  full_name='jp.co.cyberagent.stf.proto.GetAccountsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='jp.co.cyberagent.stf.proto.GetAccountsResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='accounts', full_name='jp.co.cyberagent.stf.proto.GetAccountsResponse.accounts', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1888,
  serialized_end=1944,
)


_DOADDACCOUNTMENUREQUEST = _descriptor.Descriptor(
  name='DoAddAccountMenuRequest',
  full_name='jp.co.cyberagent.stf.proto.DoAddAccountMenuRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1946,
  serialized_end=1971,
)


_DOADDACCOUNTMENURESPONSE = _descriptor.Descriptor(
  name='DoAddAccountMenuResponse',
  full_name='jp.co.cyberagent.stf.proto.DoAddAccountMenuResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='jp.co.cyberagent.stf.proto.DoAddAccountMenuResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1973,
  serialized_end=2016,
)


_DOREMOVEACCOUNTREQUEST = _descriptor.Descriptor(
  name='DoRemoveAccountRequest',
  full_name='jp.co.cyberagent.stf.proto.DoRemoveAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='jp.co.cyberagent.stf.proto.DoRemoveAccountRequest.type', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account', full_name='jp.co.cyberagent.stf.proto.DoRemoveAccountRequest.account', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2018,
  serialized_end=2073,
)


_DOREMOVEACCOUNTRESPONSE = _descriptor.Descriptor(
  name='DoRemoveAccountResponse',
  full_name='jp.co.cyberagent.stf.proto.DoRemoveAccountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='jp.co.cyberagent.stf.proto.DoRemoveAccountResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2075,
  serialized_end=2117,
)


_SETRINGERMODEREQUEST = _descriptor.Descriptor(
  name='SetRingerModeRequest',
  full_name='jp.co.cyberagent.stf.proto.SetRingerModeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='jp.co.cyberagent.stf.proto.SetRingerModeRequest.mode', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2119,
  serialized_end=2195,
)


_SETRINGERMODERESPONSE = _descriptor.Descriptor(
  name='SetRingerModeResponse',
  full_name='jp.co.cyberagent.stf.proto.SetRingerModeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='jp.co.cyberagent.stf.proto.SetRingerModeResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2197,
  serialized_end=2237,
)


_GETRINGERMODEREQUEST = _descriptor.Descriptor(
  name='GetRingerModeRequest',
  full_name='jp.co.cyberagent.stf.proto.GetRingerModeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2239,
  serialized_end=2261,
)


_GETRINGERMODERESPONSE = _descriptor.Descriptor(
  name='GetRingerModeResponse',
  full_name='jp.co.cyberagent.stf.proto.GetRingerModeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='jp.co.cyberagent.stf.proto.GetRingerModeResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mode', full_name='jp.co.cyberagent.stf.proto.GetRingerModeResponse.mode', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2263,
  serialized_end=2357,
)


_SETWIFIENABLEDREQUEST = _descriptor.Descriptor(
  name='SetWifiEnabledRequest',
  full_name='jp.co.cyberagent.stf.proto.SetWifiEnabledRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='jp.co.cyberagent.stf.proto.SetWifiEnabledRequest.enabled', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2359,
  serialized_end=2399,
)


_SETWIFIENABLEDRESPONSE = _descriptor.Descriptor(
  name='SetWifiEnabledResponse',
  full_name='jp.co.cyberagent.stf.proto.SetWifiEnabledResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='jp.co.cyberagent.stf.proto.SetWifiEnabledResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2401,
  serialized_end=2442,
)


_GETWIFISTATUSREQUEST = _descriptor.Descriptor(
  name='GetWifiStatusRequest',
  full_name='jp.co.cyberagent.stf.proto.GetWifiStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2444,
  serialized_end=2466,
)


_GETWIFISTATUSRESPONSE = _descriptor.Descriptor(
  name='GetWifiStatusResponse',
  full_name='jp.co.cyberagent.stf.proto.GetWifiStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='jp.co.cyberagent.stf.proto.GetWifiStatusResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='jp.co.cyberagent.stf.proto.GetWifiStatusResponse.status', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2468,
  serialized_end=2524,
)


_GETSDSTATUSREQUEST = _descriptor.Descriptor(
  name='GetSdStatusRequest',
  full_name='jp.co.cyberagent.stf.proto.GetSdStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2526,
  serialized_end=2546,
)


_GETSDSTATUSRESPONSE = _descriptor.Descriptor(
  name='GetSdStatusResponse',
  full_name='jp.co.cyberagent.stf.proto.GetSdStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='jp.co.cyberagent.stf.proto.GetSdStatusResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mounted', full_name='jp.co.cyberagent.stf.proto.GetSdStatusResponse.mounted', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2548,
  serialized_end=2603,
)


_SETMASTERMUTEREQUEST = _descriptor.Descriptor(
  name='SetMasterMuteRequest',
  full_name='jp.co.cyberagent.stf.proto.SetMasterMuteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='jp.co.cyberagent.stf.proto.SetMasterMuteRequest.enabled', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2605,
  serialized_end=2644,
)


_SETMASTERMUTERESPONSE = _descriptor.Descriptor(
  name='SetMasterMuteResponse',
  full_name='jp.co.cyberagent.stf.proto.SetMasterMuteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='jp.co.cyberagent.stf.proto.SetMasterMuteResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2646,
  serialized_end=2686,
)


_KEYEVENTREQUEST = _descriptor.Descriptor(
  name='KeyEventRequest',
  full_name='jp.co.cyberagent.stf.proto.KeyEventRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event', full_name='jp.co.cyberagent.stf.proto.KeyEventRequest.event', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='keyCode', full_name='jp.co.cyberagent.stf.proto.KeyEventRequest.keyCode', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='shiftKey', full_name='jp.co.cyberagent.stf.proto.KeyEventRequest.shiftKey', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ctrlKey', full_name='jp.co.cyberagent.stf.proto.KeyEventRequest.ctrlKey', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='altKey', full_name='jp.co.cyberagent.stf.proto.KeyEventRequest.altKey', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='metaKey', full_name='jp.co.cyberagent.stf.proto.KeyEventRequest.metaKey', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symKey', full_name='jp.co.cyberagent.stf.proto.KeyEventRequest.symKey', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='functionKey', full_name='jp.co.cyberagent.stf.proto.KeyEventRequest.functionKey', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='capsLockKey', full_name='jp.co.cyberagent.stf.proto.KeyEventRequest.capsLockKey', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scrollLockKey', full_name='jp.co.cyberagent.stf.proto.KeyEventRequest.scrollLockKey', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='numLockKey', full_name='jp.co.cyberagent.stf.proto.KeyEventRequest.numLockKey', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2689,
  serialized_end=2945,
)


_DOTYPEREQUEST = _descriptor.Descriptor(
  name='DoTypeRequest',
  full_name='jp.co.cyberagent.stf.proto.DoTypeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='jp.co.cyberagent.stf.proto.DoTypeRequest.text', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2947,
  serialized_end=2976,
)


_SETROTATIONREQUEST = _descriptor.Descriptor(
  name='SetRotationRequest',
  full_name='jp.co.cyberagent.stf.proto.SetRotationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rotation', full_name='jp.co.cyberagent.stf.proto.SetRotationRequest.rotation', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lock', full_name='jp.co.cyberagent.stf.proto.SetRotationRequest.lock', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2978,
  serialized_end=3030,
)


_DOWAKEREQUEST = _descriptor.Descriptor(
  name='DoWakeRequest',
  full_name='jp.co.cyberagent.stf.proto.DoWakeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3032,
  serialized_end=3047,
)

_ENVELOPE.fields_by_name['type'].enum_type = _MESSAGETYPE
_BROWSERPACKAGEEVENT.fields_by_name['apps'].message_type = _BROWSERAPP
_SETCLIPBOARDREQUEST.fields_by_name['type'].enum_type = _CLIPBOARDTYPE
_GETCLIPBOARDREQUEST.fields_by_name['type'].enum_type = _CLIPBOARDTYPE
_GETCLIPBOARDRESPONSE.fields_by_name['type'].enum_type = _CLIPBOARDTYPE
_GETBROWSERSRESPONSE.fields_by_name['apps'].message_type = _BROWSERAPP
_GETPROPERTIESRESPONSE.fields_by_name['properties'].message_type = _PROPERTY
_SETRINGERMODEREQUEST.fields_by_name['mode'].enum_type = _RINGERMODE
_GETRINGERMODERESPONSE.fields_by_name['mode'].enum_type = _RINGERMODE
_KEYEVENTREQUEST.fields_by_name['event'].enum_type = _KEYEVENT
DESCRIPTOR.message_types_by_name['Envelope'] = _ENVELOPE
DESCRIPTOR.message_types_by_name['AirplaneModeEvent'] = _AIRPLANEMODEEVENT
DESCRIPTOR.message_types_by_name['BatteryEvent'] = _BATTERYEVENT
DESCRIPTOR.message_types_by_name['BrowserApp'] = _BROWSERAPP
DESCRIPTOR.message_types_by_name['BrowserPackageEvent'] = _BROWSERPACKAGEEVENT
DESCRIPTOR.message_types_by_name['ConnectivityEvent'] = _CONNECTIVITYEVENT
DESCRIPTOR.message_types_by_name['PhoneStateEvent'] = _PHONESTATEEVENT
DESCRIPTOR.message_types_by_name['RotationEvent'] = _ROTATIONEVENT
DESCRIPTOR.message_types_by_name['GetVersionRequest'] = _GETVERSIONREQUEST
DESCRIPTOR.message_types_by_name['GetVersionResponse'] = _GETVERSIONRESPONSE
DESCRIPTOR.message_types_by_name['SetKeyguardStateRequest'] = _SETKEYGUARDSTATEREQUEST
DESCRIPTOR.message_types_by_name['SetKeyguardStateResponse'] = _SETKEYGUARDSTATERESPONSE
DESCRIPTOR.message_types_by_name['SetWakeLockRequest'] = _SETWAKELOCKREQUEST
DESCRIPTOR.message_types_by_name['SetWakeLockResponse'] = _SETWAKELOCKRESPONSE
DESCRIPTOR.message_types_by_name['SetClipboardRequest'] = _SETCLIPBOARDREQUEST
DESCRIPTOR.message_types_by_name['SetClipboardResponse'] = _SETCLIPBOARDRESPONSE
DESCRIPTOR.message_types_by_name['GetClipboardRequest'] = _GETCLIPBOARDREQUEST
DESCRIPTOR.message_types_by_name['GetClipboardResponse'] = _GETCLIPBOARDRESPONSE
DESCRIPTOR.message_types_by_name['GetBrowsersRequest'] = _GETBROWSERSREQUEST
DESCRIPTOR.message_types_by_name['GetBrowsersResponse'] = _GETBROWSERSRESPONSE
DESCRIPTOR.message_types_by_name['GetDisplayRequest'] = _GETDISPLAYREQUEST
DESCRIPTOR.message_types_by_name['GetDisplayResponse'] = _GETDISPLAYRESPONSE
DESCRIPTOR.message_types_by_name['Property'] = _PROPERTY
DESCRIPTOR.message_types_by_name['GetPropertiesRequest'] = _GETPROPERTIESREQUEST
DESCRIPTOR.message_types_by_name['GetPropertiesResponse'] = _GETPROPERTIESRESPONSE
DESCRIPTOR.message_types_by_name['DoIdentifyRequest'] = _DOIDENTIFYREQUEST
DESCRIPTOR.message_types_by_name['DoIdentifyResponse'] = _DOIDENTIFYRESPONSE
DESCRIPTOR.message_types_by_name['GetAccountsRequest'] = _GETACCOUNTSREQUEST
DESCRIPTOR.message_types_by_name['GetAccountsResponse'] = _GETACCOUNTSRESPONSE
DESCRIPTOR.message_types_by_name['DoAddAccountMenuRequest'] = _DOADDACCOUNTMENUREQUEST
DESCRIPTOR.message_types_by_name['DoAddAccountMenuResponse'] = _DOADDACCOUNTMENURESPONSE
DESCRIPTOR.message_types_by_name['DoRemoveAccountRequest'] = _DOREMOVEACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['DoRemoveAccountResponse'] = _DOREMOVEACCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['SetRingerModeRequest'] = _SETRINGERMODEREQUEST
DESCRIPTOR.message_types_by_name['SetRingerModeResponse'] = _SETRINGERMODERESPONSE
DESCRIPTOR.message_types_by_name['GetRingerModeRequest'] = _GETRINGERMODEREQUEST
DESCRIPTOR.message_types_by_name['GetRingerModeResponse'] = _GETRINGERMODERESPONSE
DESCRIPTOR.message_types_by_name['SetWifiEnabledRequest'] = _SETWIFIENABLEDREQUEST
DESCRIPTOR.message_types_by_name['SetWifiEnabledResponse'] = _SETWIFIENABLEDRESPONSE
DESCRIPTOR.message_types_by_name['GetWifiStatusRequest'] = _GETWIFISTATUSREQUEST
DESCRIPTOR.message_types_by_name['GetWifiStatusResponse'] = _GETWIFISTATUSRESPONSE
DESCRIPTOR.message_types_by_name['GetSdStatusRequest'] = _GETSDSTATUSREQUEST
DESCRIPTOR.message_types_by_name['GetSdStatusResponse'] = _GETSDSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['SetMasterMuteRequest'] = _SETMASTERMUTEREQUEST
DESCRIPTOR.message_types_by_name['SetMasterMuteResponse'] = _SETMASTERMUTERESPONSE
DESCRIPTOR.message_types_by_name['KeyEventRequest'] = _KEYEVENTREQUEST
DESCRIPTOR.message_types_by_name['DoTypeRequest'] = _DOTYPEREQUEST
DESCRIPTOR.message_types_by_name['SetRotationRequest'] = _SETROTATIONREQUEST
DESCRIPTOR.message_types_by_name['DoWakeRequest'] = _DOWAKEREQUEST
DESCRIPTOR.enum_types_by_name['MessageType'] = _MESSAGETYPE
DESCRIPTOR.enum_types_by_name['ClipboardType'] = _CLIPBOARDTYPE
DESCRIPTOR.enum_types_by_name['RingerMode'] = _RINGERMODE
DESCRIPTOR.enum_types_by_name['KeyEvent'] = _KEYEVENT

Envelope = _reflection.GeneratedProtocolMessageType('Envelope', (_message.Message,), dict(
  DESCRIPTOR = _ENVELOPE,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.Envelope)
  ))
_sym_db.RegisterMessage(Envelope)

AirplaneModeEvent = _reflection.GeneratedProtocolMessageType('AirplaneModeEvent', (_message.Message,), dict(
  DESCRIPTOR = _AIRPLANEMODEEVENT,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.AirplaneModeEvent)
  ))
_sym_db.RegisterMessage(AirplaneModeEvent)

BatteryEvent = _reflection.GeneratedProtocolMessageType('BatteryEvent', (_message.Message,), dict(
  DESCRIPTOR = _BATTERYEVENT,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.BatteryEvent)
  ))
_sym_db.RegisterMessage(BatteryEvent)

BrowserApp = _reflection.GeneratedProtocolMessageType('BrowserApp', (_message.Message,), dict(
  DESCRIPTOR = _BROWSERAPP,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.BrowserApp)
  ))
_sym_db.RegisterMessage(BrowserApp)

BrowserPackageEvent = _reflection.GeneratedProtocolMessageType('BrowserPackageEvent', (_message.Message,), dict(
  DESCRIPTOR = _BROWSERPACKAGEEVENT,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.BrowserPackageEvent)
  ))
_sym_db.RegisterMessage(BrowserPackageEvent)

ConnectivityEvent = _reflection.GeneratedProtocolMessageType('ConnectivityEvent', (_message.Message,), dict(
  DESCRIPTOR = _CONNECTIVITYEVENT,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.ConnectivityEvent)
  ))
_sym_db.RegisterMessage(ConnectivityEvent)

PhoneStateEvent = _reflection.GeneratedProtocolMessageType('PhoneStateEvent', (_message.Message,), dict(
  DESCRIPTOR = _PHONESTATEEVENT,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.PhoneStateEvent)
  ))
_sym_db.RegisterMessage(PhoneStateEvent)

RotationEvent = _reflection.GeneratedProtocolMessageType('RotationEvent', (_message.Message,), dict(
  DESCRIPTOR = _ROTATIONEVENT,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.RotationEvent)
  ))
_sym_db.RegisterMessage(RotationEvent)

GetVersionRequest = _reflection.GeneratedProtocolMessageType('GetVersionRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETVERSIONREQUEST,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.GetVersionRequest)
  ))
_sym_db.RegisterMessage(GetVersionRequest)

GetVersionResponse = _reflection.GeneratedProtocolMessageType('GetVersionResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETVERSIONRESPONSE,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.GetVersionResponse)
  ))
_sym_db.RegisterMessage(GetVersionResponse)

SetKeyguardStateRequest = _reflection.GeneratedProtocolMessageType('SetKeyguardStateRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETKEYGUARDSTATEREQUEST,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.SetKeyguardStateRequest)
  ))
_sym_db.RegisterMessage(SetKeyguardStateRequest)

SetKeyguardStateResponse = _reflection.GeneratedProtocolMessageType('SetKeyguardStateResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETKEYGUARDSTATERESPONSE,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.SetKeyguardStateResponse)
  ))
_sym_db.RegisterMessage(SetKeyguardStateResponse)

SetWakeLockRequest = _reflection.GeneratedProtocolMessageType('SetWakeLockRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETWAKELOCKREQUEST,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.SetWakeLockRequest)
  ))
_sym_db.RegisterMessage(SetWakeLockRequest)

SetWakeLockResponse = _reflection.GeneratedProtocolMessageType('SetWakeLockResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETWAKELOCKRESPONSE,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.SetWakeLockResponse)
  ))
_sym_db.RegisterMessage(SetWakeLockResponse)

SetClipboardRequest = _reflection.GeneratedProtocolMessageType('SetClipboardRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCLIPBOARDREQUEST,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.SetClipboardRequest)
  ))
_sym_db.RegisterMessage(SetClipboardRequest)

SetClipboardResponse = _reflection.GeneratedProtocolMessageType('SetClipboardResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCLIPBOARDRESPONSE,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.SetClipboardResponse)
  ))
_sym_db.RegisterMessage(SetClipboardResponse)

GetClipboardRequest = _reflection.GeneratedProtocolMessageType('GetClipboardRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCLIPBOARDREQUEST,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.GetClipboardRequest)
  ))
_sym_db.RegisterMessage(GetClipboardRequest)

GetClipboardResponse = _reflection.GeneratedProtocolMessageType('GetClipboardResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETCLIPBOARDRESPONSE,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.GetClipboardResponse)
  ))
_sym_db.RegisterMessage(GetClipboardResponse)

GetBrowsersRequest = _reflection.GeneratedProtocolMessageType('GetBrowsersRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBROWSERSREQUEST,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.GetBrowsersRequest)
  ))
_sym_db.RegisterMessage(GetBrowsersRequest)

GetBrowsersResponse = _reflection.GeneratedProtocolMessageType('GetBrowsersResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETBROWSERSRESPONSE,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.GetBrowsersResponse)
  ))
_sym_db.RegisterMessage(GetBrowsersResponse)

GetDisplayRequest = _reflection.GeneratedProtocolMessageType('GetDisplayRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETDISPLAYREQUEST,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.GetDisplayRequest)
  ))
_sym_db.RegisterMessage(GetDisplayRequest)

GetDisplayResponse = _reflection.GeneratedProtocolMessageType('GetDisplayResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETDISPLAYRESPONSE,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.GetDisplayResponse)
  ))
_sym_db.RegisterMessage(GetDisplayResponse)

Property = _reflection.GeneratedProtocolMessageType('Property', (_message.Message,), dict(
  DESCRIPTOR = _PROPERTY,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.Property)
  ))
_sym_db.RegisterMessage(Property)

GetPropertiesRequest = _reflection.GeneratedProtocolMessageType('GetPropertiesRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETPROPERTIESREQUEST,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.GetPropertiesRequest)
  ))
_sym_db.RegisterMessage(GetPropertiesRequest)

GetPropertiesResponse = _reflection.GeneratedProtocolMessageType('GetPropertiesResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETPROPERTIESRESPONSE,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.GetPropertiesResponse)
  ))
_sym_db.RegisterMessage(GetPropertiesResponse)

DoIdentifyRequest = _reflection.GeneratedProtocolMessageType('DoIdentifyRequest', (_message.Message,), dict(
  DESCRIPTOR = _DOIDENTIFYREQUEST,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.DoIdentifyRequest)
  ))
_sym_db.RegisterMessage(DoIdentifyRequest)

DoIdentifyResponse = _reflection.GeneratedProtocolMessageType('DoIdentifyResponse', (_message.Message,), dict(
  DESCRIPTOR = _DOIDENTIFYRESPONSE,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.DoIdentifyResponse)
  ))
_sym_db.RegisterMessage(DoIdentifyResponse)

GetAccountsRequest = _reflection.GeneratedProtocolMessageType('GetAccountsRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETACCOUNTSREQUEST,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.GetAccountsRequest)
  ))
_sym_db.RegisterMessage(GetAccountsRequest)

GetAccountsResponse = _reflection.GeneratedProtocolMessageType('GetAccountsResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETACCOUNTSRESPONSE,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.GetAccountsResponse)
  ))
_sym_db.RegisterMessage(GetAccountsResponse)

DoAddAccountMenuRequest = _reflection.GeneratedProtocolMessageType('DoAddAccountMenuRequest', (_message.Message,), dict(
  DESCRIPTOR = _DOADDACCOUNTMENUREQUEST,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.DoAddAccountMenuRequest)
  ))
_sym_db.RegisterMessage(DoAddAccountMenuRequest)

DoAddAccountMenuResponse = _reflection.GeneratedProtocolMessageType('DoAddAccountMenuResponse', (_message.Message,), dict(
  DESCRIPTOR = _DOADDACCOUNTMENURESPONSE,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.DoAddAccountMenuResponse)
  ))
_sym_db.RegisterMessage(DoAddAccountMenuResponse)

DoRemoveAccountRequest = _reflection.GeneratedProtocolMessageType('DoRemoveAccountRequest', (_message.Message,), dict(
  DESCRIPTOR = _DOREMOVEACCOUNTREQUEST,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.DoRemoveAccountRequest)
  ))
_sym_db.RegisterMessage(DoRemoveAccountRequest)

DoRemoveAccountResponse = _reflection.GeneratedProtocolMessageType('DoRemoveAccountResponse', (_message.Message,), dict(
  DESCRIPTOR = _DOREMOVEACCOUNTRESPONSE,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.DoRemoveAccountResponse)
  ))
_sym_db.RegisterMessage(DoRemoveAccountResponse)

SetRingerModeRequest = _reflection.GeneratedProtocolMessageType('SetRingerModeRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETRINGERMODEREQUEST,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.SetRingerModeRequest)
  ))
_sym_db.RegisterMessage(SetRingerModeRequest)

SetRingerModeResponse = _reflection.GeneratedProtocolMessageType('SetRingerModeResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETRINGERMODERESPONSE,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.SetRingerModeResponse)
  ))
_sym_db.RegisterMessage(SetRingerModeResponse)

GetRingerModeRequest = _reflection.GeneratedProtocolMessageType('GetRingerModeRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETRINGERMODEREQUEST,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.GetRingerModeRequest)
  ))
_sym_db.RegisterMessage(GetRingerModeRequest)

GetRingerModeResponse = _reflection.GeneratedProtocolMessageType('GetRingerModeResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETRINGERMODERESPONSE,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.GetRingerModeResponse)
  ))
_sym_db.RegisterMessage(GetRingerModeResponse)

SetWifiEnabledRequest = _reflection.GeneratedProtocolMessageType('SetWifiEnabledRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETWIFIENABLEDREQUEST,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.SetWifiEnabledRequest)
  ))
_sym_db.RegisterMessage(SetWifiEnabledRequest)

SetWifiEnabledResponse = _reflection.GeneratedProtocolMessageType('SetWifiEnabledResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETWIFIENABLEDRESPONSE,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.SetWifiEnabledResponse)
  ))
_sym_db.RegisterMessage(SetWifiEnabledResponse)

GetWifiStatusRequest = _reflection.GeneratedProtocolMessageType('GetWifiStatusRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETWIFISTATUSREQUEST,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.GetWifiStatusRequest)
  ))
_sym_db.RegisterMessage(GetWifiStatusRequest)

GetWifiStatusResponse = _reflection.GeneratedProtocolMessageType('GetWifiStatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETWIFISTATUSRESPONSE,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.GetWifiStatusResponse)
  ))
_sym_db.RegisterMessage(GetWifiStatusResponse)

GetSdStatusRequest = _reflection.GeneratedProtocolMessageType('GetSdStatusRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETSDSTATUSREQUEST,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.GetSdStatusRequest)
  ))
_sym_db.RegisterMessage(GetSdStatusRequest)

GetSdStatusResponse = _reflection.GeneratedProtocolMessageType('GetSdStatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETSDSTATUSRESPONSE,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.GetSdStatusResponse)
  ))
_sym_db.RegisterMessage(GetSdStatusResponse)

SetMasterMuteRequest = _reflection.GeneratedProtocolMessageType('SetMasterMuteRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETMASTERMUTEREQUEST,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.SetMasterMuteRequest)
  ))
_sym_db.RegisterMessage(SetMasterMuteRequest)

SetMasterMuteResponse = _reflection.GeneratedProtocolMessageType('SetMasterMuteResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETMASTERMUTERESPONSE,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.SetMasterMuteResponse)
  ))
_sym_db.RegisterMessage(SetMasterMuteResponse)

KeyEventRequest = _reflection.GeneratedProtocolMessageType('KeyEventRequest', (_message.Message,), dict(
  DESCRIPTOR = _KEYEVENTREQUEST,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.KeyEventRequest)
  ))
_sym_db.RegisterMessage(KeyEventRequest)

DoTypeRequest = _reflection.GeneratedProtocolMessageType('DoTypeRequest', (_message.Message,), dict(
  DESCRIPTOR = _DOTYPEREQUEST,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.DoTypeRequest)
  ))
_sym_db.RegisterMessage(DoTypeRequest)

SetRotationRequest = _reflection.GeneratedProtocolMessageType('SetRotationRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETROTATIONREQUEST,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.SetRotationRequest)
  ))
_sym_db.RegisterMessage(SetRotationRequest)

DoWakeRequest = _reflection.GeneratedProtocolMessageType('DoWakeRequest', (_message.Message,), dict(
  DESCRIPTOR = _DOWAKEREQUEST,
  __module__ = 'stfwire_pb2'
  # @@protoc_insertion_point(class_scope:jp.co.cyberagent.stf.proto.DoWakeRequest)
  ))
_sym_db.RegisterMessage(DoWakeRequest)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\004Wire'))
# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python
# coding: utf-8
#
# Usage: python -matx screen [-s 0.8]

import os
import time
import traceback
import cv2
from functools import partial

from atx.adbkit.client import Client
from atx.adbkit.device import Device
from atx.adbkit.mixins import MinicapStreamMixin, RotationWatcherMixin, MinitouchStreamMixin

class AdbWrapper(RotationWatcherMixin, MinicapStreamMixin, MinitouchStreamMixin, Device):
    def __init__(self, *args, **kwargs):
        super(self.__class__, self).__init__(*args, **kwargs)
        self.open_rotation_watcher(on_rotation_change=lambda v: self.open_minicap_stream())
        self.open_minitouch_stream()

    def send_touch(self, cmd):
        self._MinitouchStreamMixin__touch_queue.put(cmd)

    def input(self, char):
        self.shell('input', 'text', char)

def get_adb(host, port, serial):
    client = Client(host, port)
    if serial is None:
        serial = list(client.devices().keys())[0]
    return AdbWrapper(client, serial)

__dir__ = os.path.dirname(os.path.abspath(__file__))

def screen_with_controls(host, port, serial, scale=0.5):
    from PIL import Image, ImageTk
    import Tkinter as tk
    import tkFileDialog

    adb = get_adb(host, port, serial)

    class Screen(object):
        def __init__(self):
            self.root = tk.Tk()
            self.root.title('Sync Screen')
            # self.image = Image.open(os.path.join(__dir__, 'static', 'screen.png'))
            self.image = None
            self.tkimage = None
            self.canvas_image = None

            self.make_toolbar()
            self.make_canvas()

        def make_toolbar(self):
            # tools: capture, power, home, menu, back, volume_up, volume_down, turn_screen, keymapping_settings
            toolbar = tk.Frame(self.root)
            self.icons = [] # need to keep a reference for tk images. wtf.

            def capture():
                if self.image is None:
                    print 'Not initialized, try later.'
                    return
                d = tkFileDialog.asksaveasfilename(filetypes=(('Images', '*.png;*.jpg;'),), initialfile='screen.png')
                if not d: # canceled
                    return
                if not d.endswith('.png') and not d.endswith('.jpg'):
                    d += '.png'
                print 'Save to', d
                self.image.save(d)

            icon = ImageTk.PhotoImage(file=os.path.join(__dir__, 'static', 'icons', 'save.ico'))
            tk.Button(toolbar, image=icon, command=capture).pack(side=tk.LEFT, padx=2, pady=2)
            self.icons.append(icon)

            # def rotate():
            #     print 'rotate screen (Not Implemented yet.)'
            # icon = ImageTk.PhotoImage(file=os.path.join(__dir__, 'static', 'icons', 'rotate.ico'))
            # tk.Button(toolbar, image=icon, command=rotate).pack(side=tk.LEFT, padx=2, pady=2)
            # self.icons.append(icon)

            for key in ('power', 'home', 'menu', 'back', 'volume_up', 'volume_down'):
                icon = ImageTk.PhotoImage(file=os.path.join(__dir__, 'static', 'icons', '%s.ico' % key))
                self.icons.append(icon)
                b = tk.Button(toolbar, image=icon, command=lambda k=key:adb.keyevent('KEYCODE_%s' % k.upper()))
                b.pack(side=tk.LEFT, padx=2, pady=2)

            toolbar.pack(side=tk.TOP, fill=tk.X)

        def make_canvas(self):
            # screen canvas, bind mouse input & keyboard input
            self.canvas = tk.Canvas(self.root, bg='black', bd=0, highlightthickness=0)
            self.canvas.pack()

            def _screen2touch(w, h, o, x, y):
                '''convert touch position'''
                if o == 0:
                    return x, y
                elif o == 1: # landscape-right
                    return w-y, x
                elif o == 2: # upsidedown
                    return w-x, h-y
                elif o == 3: # landscape-left
                    return h-x, y
                return x, y
            
            w, h, o = adb.display
            screen2touch = partial(_screen2touch, w, h, o)

            def on_mouse_down(event):
                self.canvas.focus_set()
                x, y = int(event.x/scale), int(event.y/scale)
                x, y = screen2touch(x, y)
                adb.send_touch('d 0 %d %d 30\nc\n' % (x, y))

            def on_mouse_up(event):
                adb.send_touch('u 0\nc\n')

            def on_mouse_drag(event):
                x, y = int(event.x/scale), int(event.y/scale)
                x, y = screen2touch(x, y)
                adb.send_touch('m 0 %d %d 30\nc\n' % (x, y))

            self.canvas.bind('<ButtonPress-1>', on_mouse_down)
            self.canvas.bind('<ButtonRelease-1>', on_mouse_up)
            self.canvas.bind('<B1-Motion>', on_mouse_drag)

            keymap = {'\r':'KEYCODE_ENTER', ' ':'KEYCODE_SPACE', '\x08':'KEYCODE_DEL', }

            def on_key(event):
                c = event.char
                # print 'key pressed', repr(c), type(c)
                if c in 'adbcdefghijklmnopqrstuvwxyz0123456789':
                    adb.input(c)
                    return 'break'
                if c in keymap:
                    adb.keyevent(keymap[c])
                    return 'break'

            self.canvas.bind('<Key>', on_key)

        def _refresh_screen(self):
            img = adb.screenshot_cv2()
            if scale != 1.0:
                h, w = img.shape[:2]
                h, w = int(scale*h), int(scale*w)
                img = cv2.resize(img, (w, h))

            self.image = Image.fromarray(img[:, :, ::-1])
            self.tkimage = ImageTk.PhotoImage(self.image)
            w, h = self.image.size
            self.canvas.config(width=w, height=h)
            if self.canvas_image is None:
                self.canvas_image = self.canvas.create_image(0, 0, anchor=tk.NW, image=self.tkimage)
            else:
                self.canvas.itemconfig(self.canvas_image, image=self.tkimage)

            self.root.after(10, self._refresh_screen)

        def run(self):
            self._refresh_screen()
            self.root.mainloop()

    s = Screen()

    img = adb.screenshot_cv2()
    while img is None:
        time.sleep(1)
        img = adb.screenshot_cv2()

    s.run()

def screen_simple(host, port, serial, scale=0.5):
    adb = get_adb(host, port, serial)

    img = adb.screenshot_cv2()
    while img is None:
        time.sleep(1)
        img = adb.screenshot_cv2()

    print 'Press Ctrl-C or Esc to quit.'

    winname = 'Sync Screen'
    cv2.namedWindow(winname)
    while True:
        try:
            img = adb.screenshot_cv2()
            if scale != 1.0:
                h, w = img.shape[:2]
                h, w = int(scale*h), int(scale*w)
                img = cv2.resize(img, (w, h))
            cv2.imshow(winname, img)
            key = cv2.waitKey(10)
            if key == 27: # Escape
                break
        except KeyboardInterrupt:
            print 'Done'
            break
        except:
            traceback.print_exc()
            break

    cv2.destroyWindow(winname)

def main(serial=None, host=None, port=None, scale=0.5, simple=False):
    '''interact'''
    if simple:
        screen_simple(host, port, serial, scale)
    else:
        screen_with_controls(host, port, serial, scale)

if __name__ == '__main__':
    main()


#!/usr/bin/env python
# coding: utf-8

from __future__ import print_function

import sys
try:
    import maproxy.proxyserver
except:
    sys.exit("Require maproxy installed. Run: pip install maproxy")

import tornado.ioloop
import socket


def main(forward=26944, host='127.0.0.1', listen=5555):
    '''
    Args:
        - forward(int): local forward port
        - host(string): local forward host
        - listen(int): listen port
    '''
    # HTTP->HTTP: On your computer, browse to "http://127.0.0.1:81/" and you'll get http://www.google.com
    server = maproxy.proxyserver.ProxyServer("127.0.0.1", forward)
    server.listen(listen)
    print("Local IP:", socket.gethostbyname(socket.gethostname()))
    print("0.0.0.0:{} -> {}:{}".format(listen, host, forward))
    tornado.ioloop.IOLoop.instance().start()

if __name__ == '__main__':
    main()


# coding: utf-8
#
'''
To install airtest, download get-airtest.py

    python get-airtest.py

Many requirements will be install automaticly.

    pycrypto-2.6.win32-py2.7
    pyparsing-2.0.2.win32-py2.7
    numpy-MKL-1.8.1.win32-py2.7
    python-dateutil-2.2.win32-py2.7
    matplotlib-1.3.1.win32-py2.7
    Pillow-2.4.0.win32-py2.7
    pip-1.5.6.win32-py2.7
    setuptools-5.4.2.win32-py2.7
    opencv-python-2.4.9.win32-py2.7
'''


import sys
import platform
import subprocess

CDN_PREFIX = 'http://goandroid.qiniudn.com/airtest/'


def log(msg):
    print '>>> LOG:', msg


def err(msg):
    print '>>> ERR:', msg
    raw_input('Press Enter to exit: ')
    sys.exit(1)


# Check
if not platform.system() == 'Windows':
    err('Script only support windows platform')

pyver = platform.python_version()
if not pyver.startswith('2.7'):
    err('Need python version 2.7.*, not %s' % (pyver))

try:
    import pip
except:
    log('Install pip')
    # import urllib
    # code = urllib.urlopen('https://bootstrap.pypa.io/get-pip.py').read()
    # exec code # Will exit, not a ok way.
    # print 'Next'
    code = subprocess.Popen(['easy_install', CDN_PREFIX+'7-pip-1.5.6.win32-py2.7.exe']).wait()
    if code == 0:
        subprocess.Popen(['python', sys.argv[0]]).wait()
        sys.exit(0)

installed = {}
for soft in pip.pip.get_installed_distributions():
    installed[soft.project_name] = soft.version


requirements = [
    ['pyparsing', '2.0.2', '2-pyparsing-2.0.2.win32-py2.7.exe'],
    ['numpy', '1.8.1', '3-numpy-MKL-1.8.1.win32-py2.7.exe'],
    ['python-dateutil', '2.2', '4-python-dateutil-2.2.win32-py2.7.exe'],
    ['matplotlib', '1.3.1', '5-matplotlib-1.3.1.win32-py2.7.exe'],
    ['pillow', '2.4.0', '6-Pillow-2.4.0.win32-py2.7.exe'],
    ['opencv-python', '2.4.9', '9-opencv-python-2.4.9.win32-py2.7.exe'],
    ['pycrypto', '2.6', '10-pycrypto-2.6.win32-py2.7.exe']
]
    #['setuptools', '5.4.2', '8-setuptools-5.4.2.win32-py2.7.exe'],

for name, ver, fname in requirements:
    if installed.get(name) == ver:
        print 'Already installed "%s"' % name
        continue
    #print installed.get(name), ver, name
    print 'Downloading', name, ver
    p = subprocess.Popen(['easy_install', CDN_PREFIX+fname])
    p.wait()

os.system('pip install -i http://pypi.douban.com/simple airtest')



# coding: utf-8

import os
import sys
import logging
import webbrowser
import socket
import time
import json
import traceback

import cv2
import tornado.ioloop
import tornado.web
import tornado.websocket
from tornado.concurrent import run_on_executor
from concurrent.futures import ThreadPoolExecutor   # `pip install futures` for python2

import atx
from atx import logutils
from atx import imutils
from atx import base


__dir__ = os.path.dirname(os.path.abspath(__file__))
log = logutils.getLogger("webide", level=logging.DEBUG)
log.setLevel(logging.DEBUG)


IMAGE_PATH = ['.', 'imgs', 'images']
workdir = '.'
device = None
atx_settings = {}


def read_file(filename, default=''):
    if not os.path.isfile(filename):
        return default
    with open(filename, 'rb') as f:
        return f.read()

def write_file(filename, content):
    with open(filename, 'w') as f:
        f.write(content.encode('utf-8'))

def get_valid_port():
    for port in range(10010, 10100):
        sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        result = sock.connect_ex(('127.0.0.1', port))
        sock.close()
        if result != 0:
            return port
    raise SystemError("Can not find a unused port, amazing!")


class FakeStdout(object):
    def __init__(self, fn=sys.stdout.write):
        self._fn = fn

    def write(self, s):
        self._fn(s)

    def flush(self):
        pass


class ImageHandler(tornado.web.RequestHandler):
    def get(self):
        imgs = base.list_images(path=IMAGE_PATH)
        images = []
        for name in imgs:
            realpath = name.replace('\\', '/') # fix for windows
            name = os.path.basename(name).split('@')[0]
            images.append([name, realpath])
        self.write({
            'images': images, 
            'baseURL': self.request.protocol + '://' + self.request.host+'/static_imgs/'
        })


class MainHandler(tornado.web.RequestHandler):
    def get(self):
        imgs = base.list_images(path=IMAGE_PATH)
        imgs = [(os.path.basename(name), name) for name in imgs]
        self.render('index.html', images=imgs)

    def post(self):
        print self.get_argument('xml_text')
        self.write("Good")


class DebugWebSocket(tornado.websocket.WebSocketHandler):
    executor = ThreadPoolExecutor(max_workers=1)

    def open(self):
        log.info("WebSocket connected")
        self._run = False

    def _highlight_block(self, id):
        self.write_message({'type': 'highlight', 'id': id})
        if not self._run:
            raise RuntimeError("stopped")
        else:
            time.sleep(.1)

    def write_console(self, s):
        self.write_message({'type': 'console', 'output': s})

    def run_blockly(self, code):
        filename = '__tmp.py'
        fake_sysout = FakeStdout(self.write_console)

        __sysout = sys.stdout
        sys.stdout = fake_sysout # TODOs
        self.write_message({'type': 'console', 'output': '# '+time.strftime('%H:%M:%S') + ' start running\n'})
        try:
            # python code always UTF-8
            code = code.encode('utf-8')
            # hot patch
            code = code.replace('atx.click_image', 'd.click_image')

            exec code in {
                'highlight_block': self._highlight_block,
                '__name__': '__main__',
                '__file__': filename}
        except RuntimeError as e:
            if str(e) != 'stopped':
                raise
            print 'Program stopped'
        except Exception as e:
            self.write_message({'type': 'traceback', 'output': traceback.format_exc()})
        finally:
            self._run = False
            self.write_message({'type': 'run', 'status': 'ready'})
            sys.stdout = __sysout
        
    @run_on_executor
    def background_task(self, code):
        self.write_message({'type': 'run', 'status': 'running'})
        self.run_blockly(code)
        return True

    @tornado.gen.coroutine
    def on_message(self, message_text):
        message = None
        try:
            message = json.loads(message_text)
        except:
            print 'Invalid message from browser:', message_text
            return
        command = message.get('command')

        if command == 'refresh':
            imgs = base.list_images(path=IMAGE_PATH)
            imgs = [dict(
                path=name.replace('\\', '/'), name=os.path.basename(name)) for name in imgs]
            self.write_message({'type': 'image_list', 'data': list(imgs)})
        elif command == 'stop':
            self._run = False
            self.write_message({'type': 'run', 'notify': '停止中'})
        elif command == 'run':
            if self._run:
                self.write_message({'type': 'run', 'notify': '运行中'})
                return
            self._run = True
            res = yield self.background_task(message.get('code'))
            self.write_message({'type': 'run', 'status': 'ready', 'notify': '运行结束', 'result': res})
        else:
            self.write_message(u"You said: " + message)

    def on_close(self):
        log.info("WebSocket closed")
    
    def check_origin(self, origin):
        return True


class WorkspaceHandler(tornado.web.RequestHandler):
    def get(self):
        ret = {}
        ret['xml_text'] = read_file('blockly.xml', default='<xml xmlns="http://www.w3.org/1999/xhtml"></xml>')
        ret['python_text'] = read_file('blockly.py')
        self.write(ret)

    def post(self):
        log.info("Save workspace")
        xml_text = self.get_argument('xml_text')
        python_text = self.get_argument('python_text')
        write_file('blockly.xml', xml_text)
        write_file('blockly.py', python_text)


class ScreenshotHandler(tornado.web.RequestHandler):
    def get(self):
        d = atx.connect(**atx_settings)
        d.screenshot('_screen.png')

        self.set_header('Content-Type', 'image/png')
        with open('_screen.png', 'rb') as f:
            while 1:
                data = f.read(16000)
                if not data:
                    break
                self.write(data)
        self.finish()

    def post(self):
        raw_image = self.get_argument('raw_image')
        filename = self.get_argument('filename')
        image = imutils.open(raw_image)
        cv2.imwrite(filename, image)
        self.write({'status': 'ok'})


class StaticFileHandler(tornado.web.StaticFileHandler):
    def get(self, path=None, include_body=True):
        path = path.encode(base.SYSTEM_ENCODING) # fix for windows
        return super(StaticFileHandler, self).get(path, include_body)


def make_app(settings={}):
    static_path = os.getcwd()
    application = tornado.web.Application([
        (r"/", MainHandler),
        (r'/ws', DebugWebSocket), # code debug
        (r"/workspace", WorkspaceHandler), # save and write workspace
        (r"/images/screenshot", ScreenshotHandler),
        (r'/api/images', ImageHandler),
        (r'/static_imgs/(.*)', StaticFileHandler, {'path': static_path}),
    ], **settings)
    return application


def main(web_port=None, host=None, port=None, open_browser=True, workdir='.'):
    application = make_app({
        'static_path': os.path.join(__dir__, 'static'),
        'template_path': os.path.join(__dir__, 'static'),
        'debug': True,
    })
    if not web_port:
        web_port = get_valid_port()

    global device
    # global workdir
    atx_settings['host'] = host
    atx_settings['port'] = port
    # device = atx.connect(host=kws.get('host'), port=kws.get('port'))
    # TODO
    # filename = 'blockly.py'
    IMAGE_PATH.append('images/blockly')

    if open_browser:
        url = 'http://127.0.0.1:{}'.format(web_port)
        webbrowser.open(url, new=2) # 2: open new tab if possible

    application.listen(web_port)
    log.info("Server started.")
    log.info("Listening port on 127.0.0.1:{}".format(web_port))
    tornado.ioloop.IOLoop.instance().start()


if __name__ == "__main__":
    main()



#! /usr/bin/env python
# -*- coding: utf-8 -*-

import argparse
import uuid
import json
import inspect
import sys
import os
import time
from contextlib import contextmanager
from collections import defaultdict
from functools import partial

import tornado.web
import tornado.escape
from tornado import gen
from tornado.ioloop import IOLoop
from tornado.netutil import bind_unix_socket
from tornado.httpserver import HTTPServer
from tornado.queues import Queue, QueueEmpty

import requests
import requests_unixsocket
requests_unixsocket.monkeypatch()


class IndexHandler(tornado.web.RequestHandler):
    def get(self):
        self.write('atx.taskqueue')

    def delete(self):
        self.write('Quit')
        IOLoop.instance().stop()


class TaskQueueHandler(tornado.web.RequestHandler):
    ques = defaultdict(partial(Queue, maxsize=2))
    results = {}

    @gen.coroutine
    def get(self, udid):
        ''' get new task '''
        timeout = self.get_argument('timeout', 20.0)
        if timeout is not None:
            timeout = float(timeout)
        que = self.ques[udid]
        try:
            item = yield que.get(timeout=time.time()+timeout) # timeout is a timestamp, strange
            print 'get from queue:', item
            self.write(item)
            que.task_done()
        except gen.TimeoutError:
            print 'timeout'
            self.write('')
        finally:
            self.finish()

    @gen.coroutine
    def post(self, udid):
        ''' add new task '''
        que = self.ques[udid]
        timeout = self.get_argument('timeout', 10.0)
        if timeout is not None:
            timeout = float(timeout)
        data = tornado.escape.json_decode(self.request.body)
        data = {'id': str(uuid.uuid1()), 'data': data}
        yield que.put(data, timeout=time.time()+timeout)
        print 'post, queue size:', que.qsize()
        self.write({'id': data['id']})
        self.finish()

    @gen.coroutine
    def put(self, udid):
        ''' finish task '''
        data = tornado.escape.json_decode(self.request.body)
        id = data['id']
        result = data['result']
        if self.results.get(id) is None:
            self.results[id] = result
        else:
            that = self.results[id]
            that.write(json.dumps(result))
            that.finish()
            self.results.pop(id, None)
        self.write('Success')
        self.finish()

    @gen.coroutine
    def patch(self, udid):
        data = tornado.escape.json_decode(self.request.body)
        id = data['id']
        timeout = float(data.get('timeout', 20.0))
        print 'Timeout:', timeout
        result = self.results.get(id)
        if result is None:
            self.results[id] = self
            yield gen.sleep(timeout)
            if self.results.get(id) == self:
                del(self.results[id])
                self.write('null')
                self.finish()
        else:
            self.write(json.dumps(result))
            self.results.pop(id, None)

    @gen.coroutine
    def delete(self, udid):
        que = self.ques[udid]
        for i in range(que.qsize()+1):
            try:
                que.get_nowait()
            except QueueEmpty:
                self.write("Queue cleaned")
                break
        else:
            self.write("Queue clean not finished yet")


def make_app(**settings):
    print settings
    return tornado.web.Application([
        (r"/", IndexHandler),
        (r"/rooms/([^/]*)", TaskQueueHandler),
    ], **settings)

def cmd_web(unix_socket, debug):
    app = make_app(debug=debug)
    server = HTTPServer(app)
    if os.path.exists(unix_socket):
        try:
            r = requests.get('http+unix://{0}'.format(unix_socket.replace('/', '%2F')))
            if r.text.strip() == 'atx.taskqueue':
                print 'Already listening'
                return
        except:
            print 'Unlink unix socket'
            os.unlink(unix_socket)

    socket = bind_unix_socket(unix_socket)
    server.add_socket(socket)
    IOLoop.current().start()

def _gen_requrl(unix_socket, room):
    return 'http+unix://{0}/rooms/{1}'.format(unix_socket.replace('/', '%2F'), room) #localhost:%d/rooms/%s' % (port, room)

def cmd_put(requrl, task_id, data):
    data = json.loads(data)
    jsondata = {'id': task_id, 'result': data}
    r = requests.put(requrl, data=json.dumps(jsondata))
    print r.text

def cmd_get(requrl, timeout):
    r = requests.get(requrl, params={'timeout': timeout})
    print r.text

def cmd_post(requrl, data):
    jsondata = json.loads(data)
    if not isinstance(jsondata, dict):
        sys.exit('data must be dict, for example: {"name": "kitty"}')
    r = requests.post(requrl, data=json.dumps(jsondata))
    print r.json()['id']

def cmd_patch(requrl, task_id):
    jsondata = {'id': task_id}
    r = requests.patch(requrl, data=json.dumps(jsondata))
    print r.text

def cmd_clean(requrl):
    r = requests.delete(requrl)
    print r.text

def cmd_quit(unix_socket):
    requrl = 'http+unix://{0}'.format(unix_socket.replace('/', '%2F'))
    r = requests.delete(requrl)
    print r.text

def _inject(func, kwargs):
    args = []
    for name in inspect.getargspec(func).args:
        args.append(kwargs.get(name))
    return func(*args)

def wrap(fn):
    def inner(parser_args):
        args = vars(parser_args)
        args['requrl'] = _gen_requrl(parser_args.unix_socket, parser_args.room)
        return _inject(fn, args)
    return inner


def main():
    ap = argparse.ArgumentParser(
        formatter_class=argparse.ArgumentDefaultsHelpFormatter)
    ap.add_argument("--room", required=False, help="udid or something")
    ap.add_argument("--unix", dest='unix_socket', required=False, default='/tmp/atx-taskqueue.sock', help="sever listen sock path")
    subp = ap.add_subparsers()

    @contextmanager
    def add_parser(name):
        yield subp.add_parser(name, formatter_class=argparse.ArgumentDefaultsHelpFormatter)

    with add_parser('web') as p:
        # p.add_argument('--daemon', action='store_true', dest='is_daemon', help='Run is background')
        p.add_argument('--debug', action='store_true', help='Run in debug mode')
        p.set_defaults(func=wrap(cmd_web))

    with add_parser('put') as p:
        p.add_argument('task_id')
        p.add_argument('data')
        p.set_defaults(func=wrap(cmd_put))

    with add_parser('get') as p:
        p.add_argument('--timeout', type=float, default=10.0)
        p.set_defaults(func=wrap(cmd_get))

    with add_parser('post') as p:
        p.add_argument('data')
        p.set_defaults(func=wrap(cmd_post))

    with add_parser('retr') as p: # retrive result
        p.add_argument('task_id')
        p.set_defaults(func=wrap(cmd_patch))

    with add_parser('clean') as p:
        p.set_defaults(func=wrap(cmd_clean))

    with add_parser('quit') as p:
        p.set_defaults(func=wrap(cmd_quit))

    args = ap.parse_args()
    args.func(args)


if __name__ == '__main__':
    main()



#!/usr/bin/env python
import tornado.ioloop
import maproxy.proxyserver
import socket

# HTTP->HTTP: On your computer, browse to "http://127.0.0.1:81/" and you'll get http://www.google.com
server = maproxy.proxyserver.ProxyServer("127.0.0.1", 26944)
server.listen(5555)
print("Local IP:", socket.gethostbyname(socket.gethostname()))
print("0.0.0.0:5555 -> 127.0.0.1:26944")
tornado.ioloop.IOLoop.instance().start()


#-*- encoding: utf-8 -*-

import bisect
import cv2
import os
import threading
import time

from atx.device import Bounds
from atx.device.android import AndroidDevice
from atx.adbkit.mixins import RotationWatcherMixin, MinicapStreamMixin

from atx.record.base import BaseRecorder, ScreenAddon, UixmlAddon
from atx.record.android_hooks import HookManager, HookConstants as HC, set_multitap
from atx.record.android_layout import AndroidLayout

class RecordDevice(RotationWatcherMixin, MinicapStreamMixin, AndroidDevice):

    def __init__(self, *args, **kwargs):
        super(RecordDevice, self).__init__(*args, **kwargs)
        self.open_rotation_watcher(on_rotation_change=lambda v: self.open_minicap_stream())

    def dumpui(self):
        xmldata = self._uiauto.dump(pretty=False)
        return xmldata

class AndroidAtomRecorder(BaseRecorder):
    '''record detailed events: TOUCH_UP, TOUCH_DOWN, TOUCH_MOVE, KEY_UP, KEY_DOWN'''

    def __init__(self, *args, **kwargs):
        self.hm = HookManager()
        super(AndroidAtomRecorder, self).__init__(*args, **kwargs)
        self.hm.register(HC.KEY_ANY, self.input_event)
        self.hm.register(HC.TOUCH_ANY, self.input_event)

    def attach(self, device):
        if self.device is not None:
            self.detach()
        self.device = device
        self.hm.set_serial(self.device.serial)

    def detach(self):
        self.unhook()
        self.device = None
        self.hm.set_serial(None)

    def hook(self):
        self.hm.hook()

    def unhook(self):
        self.hm.unhook()

    def analyze_frame(self, idx, event, status):
        e = event
        if e.msg == HC.TOUCH_MOVE:
            d = {
                'action' : 'touch_move',
                'args' : (e.slotid, e.x, e.y),
            }
        elif e.msg == HC.TOUCH_DOWN:
            d = {
                'action' : 'touch_down',
                'args' : (e.slotid, e.x, e.y),
            }
        elif e.msg == HC.TOUCH_UP:
            d = {
                'action' : 'touch_up',
                'args' : (e.slotid, e.x, e.y),
            }
        elif e.msg & HC.KEY_ANY:
            if e.msg & 0x01:
                d = {
                    'action' : 'key_down',
                    'args' : (e.key,),
                }
            else:
                d = {
                    'action' : 'key_up',
                    'args' : (e.key,),
                }
        else:
            return
        self.case_draft.append(d)

    def process_draft(self, d):
        tmpl = {
            'touch_move' : 'd.touch_move({:d}, {:d}, {:d})',
            'touch_down' : 'd.touch_down({:d}, {:d}, {:d})',
            'touch_up' : 'd.touch_up({:d}, {:d}, {:d})',
            'key_down' : 'd.key_down("{}")',
            'key_up' : 'd.key_up("{}")',
        }
        return tmpl[d['action']].format(*d['args'])

class AdbStatusAddon(object):
    __addon_name = 'adbstatus'
    __cmd_interval = 0.1
    __cmd_lock = None
    __cmd_thread = None

    __adbstatus_cache = []

    def get_adbstatus(self, t):
        if self.__cmd_thread is None:
            self.__start()
        with self.__cmd_lock:
            idx = bisect.bisect(self.__adbstatus_cache, (t, None))
            if idx != 0:
                return self.__adbstatus_cache[idx-1][1]

    def save_adbstatus(self, data, dirpath, idx):
        return data

    def load_adbstatus(self, dirpath, data):
        return data

    def __start(self):
        print 'start', self.__addon_name
        if self.__cmd_lock is None:
            self.__cmd_lock = threading.Lock()
        if self.__cmd_thread is not None:
            self.__cmd_thread._Thread_stop() # using __stop private method, not good
        self.__cmd_thread = t = threading.Thread(target=self.__cmd)
        t.setDaemon(True)
        t.start()

    def __cmd(self):
        cmd_maxnum = int(self.monitor_period/self.__cmd_interval)
        while True:
            self.__cmd_lock.acquire()
            try:
                time.sleep(self.__cmd_interval)
                if not self.running or self.device is None:
                    continue
                # tic = time.time()
                status = {
                    'activity' : self.__get_activity(),
                }
                self.__adbstatus_cache.append((time.time(), status))
                self.__adbstatus_cache = self.__adbstatus_cache[-cmd_maxnum:]
            finally:
                self.__cmd_lock.release()

    def __get_activity(self): # cost around 75ms
        try:
            package, activity = self.device.adb_device.current_app()
            return package + '/' + activity
        except:
            # traceback.print_exc()
            return

class AndroidRecorder(BaseRecorder, ScreenAddon, UixmlAddon, AdbStatusAddon):
    def __init__(self, *args, **kwargs):
        self.hm = HookManager()
        self.uilayout = AndroidLayout()
        self.nonui_activities = set()
        self.scene_detector = kwargs.pop('scene_detector', None)

        super(AndroidRecorder, self).__init__(*args, **kwargs)
        self.hm.register(HC.KEY_ANY, self.on_key)
        self.hm.register(HC.GST_TAP, self.input_event)
        self.hm.register(HC.GST_SWIPE, self.input_event)
        self.hm.register(HC.GST_DRAG, self.input_event)

    def attach(self, device):
        if self.device is not None:
            self.detach()
        self.device = device
        self.hm.set_serial(self.device.serial)

    def detach(self):
        self.unhook()
        self.device = None
        self.hm.set_serial(None)

    def hook(self):
        self.hm.hook()

    def unhook(self):
        self.hm.unhook()

    def add_nonui_activity(self, activity):
        self.nonui_activities.add(activity)

    def remove_nonui_activity(self, activity):
        self.nonui_activities.discard(activity)

    def on_key(self, event):
        if not event.msg & 0x01: # key_up
            print 'KeyEvent', event.key
            self.input_event(event)

    def serialize_event(self, event):
        e = event
        if e.msg & HC.KEY_ANY:
            return {'action':'key_event', 'args':(e.key,)}
        if e.msg == HC.GST_TAP:
            x, y = e.points[0]
            return {'action':'click', 'args':(x, y)}
        if e.msg in (HC.GST_SWIPE, HC.GST_DRAG):
            sx, sy = e.points[0]
            ex, ey = e.points[1]
            return {'action':'swipe', 'args':(sx, sy, ex, ey)}

    def analyze_frame(self, idx, event, status):
        e = event
        d = {'frameidx': idx}
        if e.msg & HC.KEY_ANY:
            d['action'] = 'key_event'
            d['args'] = (e.key,)
            self.case_draft.append(d)
            return

        uixml = status['uixml']
        screen = status['screen']
        adbstatus = status['adbstatus']
        activity = adbstatus['activity']

        analyze_ui = False
        if activity is not None and activity not in self.nonui_activities:
            if uixml is not None:
                self.uilayout.parse_xmldata(uixml)
                analyze_ui = True

        if event.msg == HC.GST_TAP:
            x, y = event.points[0]

            found_ui = False
            if analyze_ui:
                node = self.uilayout.find_clickable_node(x, y)
                if node:
                    found_ui = True
                    pnode, selector, order = self.uilayout.find_selector(node)
                    d['action'] = 'click_ui'
                    d['args'] = (pnode.iterindex, )
                    d['extra'] = (selector, order)

            # try image first when uinode not found.
            if not found_ui:
                if screen is not None:
                    bounds = find_clicked_bound(screen, x, y)
                    d['action'] = 'click_image'
                    d['args'] = (x, y, tuple(bounds))
                else:
                    d['action'] = 'click'
                    d['args'] = (x, y)

        elif event.msg in (HC.GST_SWIPE, HC.GST_DRAG):
            sx, sy = e.points[0]
            ex, ey = e.points[1]
            d['action'] = 'swipe'
            d['args'] = (sx, sy, ex, ey)

        elif event.msg == HC.GST_PINCH_IN:
            #TODO
            pass

        else:
            return

        self.case_draft.append(d)

    def process_draft(self, d):
        if not d:
            return ''
        idx = int(d['frameidx'])
        frame = self.frames[idx]
        waittime = frame['waittime']
        if d['action'] == 'key_event':
            return 'd.keyevent("{}")'.format(*d['args'])
        elif d['action'] == 'click':
            return 'd.click({}, {})'.format(*d['args'])
        elif d['action'] == 'click_ui':
            if 'extra' in d:
                selector, order = d['extra']
            else:
                uixml = open(os.path.join(self.framedir, frame['status']['uixml'])).read()
                self.uilayout.parse_xmldata(uixml)
                pnode = self.uilayout.get_index_node(int(d['args'][0]))
                selector, order = self.uilayout.get_node_selector(pnode)
            if order is None:
                return 'd(%s).click(timeout=%d)' %\
                    (', '.join(['%s=u"%s"' % item for item in selector.iteritems()]), 100*(int(waittime*10)))
            else:
                return 'objs = d(%s)\nif objs.wait.exists(timeout=%d):\n    objs[%d].click()'  %\
                    (', '.join(['%s=u"%s"' % item for item in selector.iteritems()]), 100*(int(waittime*10)), order)
        elif d['action'] == 'click_image':
            x, y, bounds = d['args']
            x, y, bounds = int(x), int(y), map(int, bounds)
            desc = get_point_desc(x, y, bounds)
            screen = cv2.imread(os.path.join(self.framedir, frame['status']['screen']))
            l, t, w, h = bounds
            img = screen[t:t+h, l:l+w]
            imgname = '%d-click.%dx%d.%s.png' % (idx, self.device_info['width'], self.device_info['height'], desc)
            imgpath = os.path.join(self.casedir, imgname)
            cv2.imwrite(imgpath, img)
            return 'd.click_image("%s")' % (imgname,)
        elif d['action'] == 'swipe':
            sx, sy, ex, ey = d['args']
            return 'd.swipe(%s, %s, %s, %s, 10)\ntime.sleep(%.2f)' % (sx, sy, ex, ey, waittime)
        else:
            print 'unsupported action', d['action']
            return ''

def find_clicked_bound(img, x, y, size=200):
    maxy, maxx = img.shape[:2]
    size = min(size, maxx, maxy)
    l, r, t, b = x-size/2, x+size/2, y-size/2, y+size/2
    if l < 0:
        l = 0
    elif r > maxx:
        l = maxx-size
    if t < 0:
        t = 0
    elif b > maxy:
        t = maxy-size
    return Bounds(l, t, size, size)

def get_point_desc(x, y, bounds):
    l, t, w, h = bounds
    cx, cy = l+w/2, t+h/2
    desc = ''
    if x < cx:
        desc += 'L%d' % int((cx-x+0.0)*100/w)
    else:
        desc += 'R%d' % int((x-cx+0.0)*100/w)
    if y < cy:
        desc += 'T%d' % int((cy-y+0.0)*100/h)
    else:
        desc += 'B%d' % int((y-cy+0.0)*100/h)
    return desc

if __name__ == '__main__':
    # from atx.record.scene_detector import SceneDetector

    # disable multitap
    set_multitap(1)

    def test():
        d = RecordDevice()
        # detector = SceneDetector('txxscene')
        rec = AndroidRecorder(d, 'testcase', realtime_analyze=True)
        rec.add_nonui_activity('com.netease.txx.mi/com.netease.txx.Client')
        rec.start()
        while True:
            try:
                time.sleep(1)
            except:
                break
        rec.stop()

    if os.path.exists(os.path.join('testcase', 'case', 'case.json')):
        AndroidRecorder.process_casefile('testcase')
    elif os.path.exists(os.path.join('testcase', 'frames', 'frames.json')):
        AndroidRecorder.analyze_frames('testcase')
    else:
        test()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# hzsunshx <2016-06-12>
# make sure only one phone connected to pc/

import unittest
import shutil
from collections import namedtuple
from mock import MagicMock, patch

import atx
from atx.ext.report import Report
from PIL import Image


class TestExtReport(unittest.TestCase):
    def setUp(self):
        self.d = atx.connect(platform='dummy')
        self.rp = Report(self.d, save_dir='tmp_report')

    def tearDown(self):
        self.rp.close()
        shutil.rmtree('tmp_report')

    def test_screenshot(self):
        assert self.rp.last_screenshot is None
        self.d.screenshot()
        assert isinstance(self.rp.last_screenshot, Image.Image)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''
nija test example
'''

import sys
import os
import airtest
import time

serialno = os.getenv('AIRTEST_PHONENO') or '10.242.62.143:5555'
appname  = os.getenv('AIRTEST_APPNAME') or 'com.netease.rz'
device = os.getenv('DEVICE') or 'android'

app = airtest.connect(serialno, appname=appname, device=device)

try:
    while True:
        app.sleep(10)
        app.takeSnapshot('%d.png' % int(time.time()))
except KeyboardInterrupt:
    print 'Exit'

